"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Server = void 0;
const tslib_1 = require("tslib");
const response_1 = require("./response");
const dino_core_1 = require("dino-core");
const FinalResponseMiddleware_1 = require("./middlewares/FinalResponseMiddleware");
const AwsRequestAdaptor_1 = require("./request/AwsRequestAdaptor");
class Server {
    load(config) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            this.applicationContext = yield dino_core_1.Dino.run(config);
            this.environment = this.applicationContext.resolve('environment');
            this.awsRequestAdaptor = new AwsRequestAdaptor_1.AwsRequestAdaptor(this.environment);
            this.intervalTimer = setInterval(this.discoverRouter.bind(this), 10);
            this.finalResponseHandler = new FinalResponseMiddleware_1.FinalResponseMiddleware(this.environment);
            this.serverType = this.environment.getOrDefault('dino:server:type', 'express');
            this.cloudProvider = this.environment.getOrDefault('dino:cloud:provider', 'google');
        });
    }
    run(req, res) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            yield this.load(undefined);
            if (this.serverType === 'express') {
                // the context will be loaded and the express server will be started
                yield Promise.resolve();
            }
            else {
                return yield this.handleServerlessMode(req, res);
            }
            // const exposedAs = environment.getOrDefault('dino:cloud:expose', 'api');
        });
    }
    handleServerlessMode(req, res) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return yield new Promise((resolve, reject) => {
                let request;
                let response;
                if (this.serverType === 'serverless' && this.cloudProvider === 'aws') {
                    // adapt aws request to express request
                    request = this.awsRequestAdaptor.adapt(req);
                    // eslint-disable-next-line @typescript-eslint/consistent-type-assertions
                    response = new response_1.ResponseImpl(resolve, request);
                }
                else {
                    request = req;
                    response = res;
                }
                if (dino_core_1.ObjectHelper.isDefined(this.router)) {
                    dino_core_1.Logger.debug('router has already been initialized...');
                    this.router.handle(request, response, this.finalResponseHandler.handle(request, response, resolve, reject));
                }
                else {
                    dino_core_1.Logger.info('router not found initialize it...');
                    const resolver = () => {
                        this.router = this.applicationContext.resolve('router');
                        clearInterval(this.intervalTimer);
                        this.router.handle(request, response, this.finalResponseHandler.handle(request, response, resolve, reject));
                    };
                    setTimeout(resolver.bind(this), 500);
                }
            });
        });
    }
    discoverRouter() {
        try {
            this.router = this.applicationContext.resolve('router');
            if (dino_core_1.ObjectHelper.isDefined(this.router)) {
                clearInterval(this.intervalTimer);
            }
        }
        catch (error) {
            // nothing to do
        }
    }
}
exports.Server = Server;
//# sourceMappingURL=Server.js.map