/// <reference types="node" />
/// <reference types="node" />
/// <reference types="node" />
/// <reference types="node" />
import { type Response as EResponse } from 'express';
import { type GenericObject } from './types';
import { type HttpException } from './exception/http.exception';
import { type CookieOptions, type Locals, type Application, type Request, type ParamsDictionary } from 'express-serve-static-core';
import { type OutgoingHttpHeaders } from 'http';
import { type Socket } from 'net';
import { type ParsedQs } from 'qs';
export type ResponsePayload = GenericObject | string | undefined;
export type ErrorResponsePayload = GenericObject | HttpException | Error | undefined;
interface Chunk {
    chunk: any;
    encoding: BufferEncoding;
}
/**
 * The response that is returned from the API handler.
 * @public
 */
export interface Response extends EResponse {
    body: ResponsePayload;
}
export declare class ResponseImpl implements Response {
    body: ResponsePayload;
    statusCode: number;
    statusMessage: string;
    strictContentLength: boolean;
    app: Application<Record<string, any>>;
    locals: Record<string, any> & Locals;
    charset: string;
    chunkedEncoding: boolean;
    shouldKeepAlive: boolean;
    useChunkedEncodingByDefault: boolean;
    sendDate: boolean;
    finished: boolean;
    connection: Socket | null;
    socket: Socket | null;
    writable: boolean;
    writableEnded: boolean;
    writableFinished: boolean;
    writableHighWaterMark: number;
    writableLength: number;
    writableObjectMode: boolean;
    writableCorked: number;
    destroyed: boolean;
    closed: boolean;
    errored: Error | null;
    writableNeedDrain: boolean;
    headersSent: boolean;
    headers: GenericObject;
    readonly req: Request<ParamsDictionary, any, any, ParsedQs, Record<string, any>>;
    private readonly callback;
    constructor(callback: (...args: any) => void, req: Request<ParamsDictionary, any, any, ParsedQs, Record<string, any>>);
    sendfile(_path: unknown, _options?: unknown, _fn?: unknown): void;
    status(code: number): any;
    sendStatus(_code: number): this;
    links(_links: any): this;
    send(body?: GenericObject): any;
    json(body?: GenericObject): any;
    jsonp(body?: GenericObject): any;
    sendFile(_path: unknown, _options?: unknown, _fn?: unknown): void;
    download(_path: unknown, _filename?: unknown, _options?: unknown, _fn?: unknown): void;
    contentType(_type: string): this;
    type(_type: string): this;
    format(obj: GenericObject): this;
    attachment(_filename?: string | undefined): this;
    set(field: string, value?: unknown): this;
    header(field: string, value?: unknown): this;
    get(field: string): string | undefined;
    clearCookie(_name: string, _options?: CookieOptions | undefined): this;
    cookie(_name: unknown, _val: unknown, _options?: unknown): this;
    location(_url: string): this;
    redirect(_url: unknown, _status?: unknown): void;
    render(_view: unknown, _options?: unknown, _callback?: unknown): void;
    vary(_field: string): this;
    append(field: string, value?: string | string[] | undefined): this;
    assignSocket(_socket: Socket): void;
    detachSocket(_socket: Socket): void;
    writeContinue(_callback?: (() => void) | undefined): void;
    writeEarlyHints(_hints: Record<string, string | string[]>, _callback?: (() => void) | undefined): void;
    writeHead(_statusCode: unknown, _statusMessage?: unknown, _headers?: unknown): this;
    writeProcessing(): void;
    setTimeout(_msecs: number, _callback?: (() => void) | undefined): this;
    setHeader(name: string, value: string | number | readonly string[]): this;
    appendHeader(_name: string, _value: string | readonly string[]): this;
    getHeader(name: string): string | number | string[] | undefined;
    getHeaders(): OutgoingHttpHeaders;
    getHeaderNames(): string[];
    hasHeader(_name: string): boolean;
    removeHeader(_name: string): void;
    addTrailers(_headers: OutgoingHttpHeaders | ReadonlyArray<[string, string]>): void;
    flushHeaders(): void;
    _write(_chunk: any, _encoding: BufferEncoding, _callback: (error?: Error | null | undefined) => void): void;
    _writev?(_chunks: Chunk[], _callback: (error?: Error | null | undefined) => void): void;
    _construct?(_callback: (error?: Error | null | undefined) => void): void;
    _destroy(_error: Error | null, _callback: (error?: Error | null | undefined) => void): void;
    _final(_callback: (error?: Error | null | undefined) => void): void;
    write(_chunk: unknown, _encoding?: unknown, _callback?: unknown): boolean;
    setDefaultEncoding(_encoding: BufferEncoding): this;
    end(_chunk?: unknown, _encoding?: unknown, _cb?: unknown): this;
    cork(): void;
    uncork(): void;
    destroy(_error?: Error | undefined): this;
    addListener(_event: unknown, _listener: unknown): this;
    emit(_event: unknown, _src?: unknown, ..._rest: unknown[]): boolean;
    on(_event: unknown, _listener: unknown): this;
    once(_event: unknown, _listener: unknown): this;
    prependListener(_event: unknown, _listener: unknown): this;
    prependOnceListener(_event: unknown, _listener: unknown): this;
    removeListener(_event: unknown, _listener: unknown): this;
    pipe<T extends NodeJS.WritableStream>(_destination: T, _options?: {
        end?: boolean | undefined;
    } | undefined): T;
    compose<T extends NodeJS.ReadableStream>(_stream: ((source: any) => void) | T | Iterable<T> | AsyncIterable<T>, _options?: {
        signal: AbortSignal;
    } | undefined): T;
    off(_eventName: string | symbol, _listener: (...args: any[]) => void): this;
    removeAllListeners(_event?: string | symbol | undefined): this;
    setMaxListeners(_n: number): this;
    getMaxListeners(): number;
    listeners(_eventName: string | symbol): Function[];
    rawListeners(_eventName: string | symbol): Function[];
    listenerCount(_eventName: string | symbol, _listener?: Function | undefined): number;
    eventNames(): Array<string | symbol>;
}
export {};
