"use strict";
//    Copyright 2018 Quirino Brizi [quirino.brizi@gmail.com]
//
//    Licensed under the Apache License, Version 2.0 (the "License");
//    you may not use this file except in compliance with the License.
//    You may obtain a copy of the License at
//
//        http://www.apache.org/licenses/LICENSE-2.0
//
//    Unless required by applicable law or agreed to in writing, software
//    distributed under the License is distributed on an "AS IS" BASIS,
//    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//    See the License for the specific language governing permissions and
//    limitations under the License.
Object.defineProperty(exports, "__esModule", { value: true });
exports.ResponseImpl = void 0;
const dino_core_1 = require("dino-core");
// eslint-disable-next-line @typescript-eslint/no-extraneous-class
class EventEmitter {
}
class ResponseImpl {
    constructor(callback, req) {
        this.statusMessage = '';
        this.strictContentLength = false;
        // eslint-disable-next-line @typescript-eslint/consistent-type-assertions
        this.app = {};
        this.locals = {};
        this.charset = 'UTF-8';
        this.chunkedEncoding = false;
        this.shouldKeepAlive = false;
        this.useChunkedEncodingByDefault = false;
        this.sendDate = false;
        this.finished = false;
        this.connection = null;
        this.socket = null;
        this.writable = false;
        this.writableEnded = false;
        this.writableFinished = false;
        this.writableHighWaterMark = 0;
        this.writableLength = 0;
        this.writableObjectMode = false;
        this.writableCorked = 0;
        this.destroyed = false;
        this.closed = false;
        this.errored = null;
        this.writableNeedDrain = false;
        this.headersSent = false;
        this.headers = {};
        this.req = req;
        this.callback = callback;
    }
    sendfile(_path, _options, _fn) {
        throw new Error('Method not implemented.');
    }
    [EventEmitter.captureRejectionSymbol](_error, _event, ..._args) {
        throw new Error('Method not implemented.');
    }
    status(code) {
        this.statusCode = code;
        return this;
    }
    sendStatus(_code) {
        throw new Error('Method not implemented.');
    }
    links(_links) {
        throw new Error('Method not implemented.');
    }
    send(body) {
        this.callback(body);
        return this;
    }
    json(body) {
        return this.send(body);
    }
    jsonp(body) {
        return this.send(body);
    }
    sendFile(_path, _options, _fn) {
        throw new Error('Method not implemented.');
    }
    download(_path, _filename, _options, _fn) {
        throw new Error('Method not implemented.');
    }
    contentType(_type) {
        throw new Error('Method not implemented.');
    }
    type(_type) {
        throw new Error('Method not implemented.');
    }
    format(obj) {
        const req = this.req;
        const next = req.next;
        // const keys = Object.keys(obj).filter(function (v) {
        //   return v !== 'default'
        // })
        // const key = keys.length > 0 ? req.accepts(keys) : undefined
        // this.vary('Accept')
        // if (key !== undefined) {
        //   this.set('Content-Type', normalizeType(key).value)
        //   obj[key](req, this, next)
        // } else
        if (obj.default !== undefined) {
            obj.default(req, this, next);
        }
        //  else {
        //   next(
        //     createError(406, {
        //       types: normalizeTypes(keys).map(function (o) {
        //         return o.value
        //       })
        //     })
        //   )
        // }
        return this;
    }
    attachment(_filename) {
        throw new Error('Method not implemented.');
    }
    set(field, value) {
        this.headers[field] = value;
        return this;
    }
    header(field, value) {
        if (dino_core_1.ObjectHelper.isDefined(value)) {
            this.headers[field] = value;
        }
        return this;
    }
    get(field) {
        return this.headers[field];
    }
    clearCookie(_name, _options) {
        throw new Error('Method not implemented.');
    }
    cookie(_name, _val, _options) {
        throw new Error('Method not implemented.');
    }
    location(_url) {
        throw new Error('Method not implemented.');
    }
    redirect(_url, _status) {
        throw new Error('Method not implemented.');
    }
    render(_view, _options, _callback) {
        throw new Error('Method not implemented.');
    }
    vary(_field) {
        throw new Error('Method not implemented.');
    }
    append(field, value) {
        this.set(field, value);
        return this;
    }
    assignSocket(_socket) {
        throw new Error('Method not implemented.');
    }
    detachSocket(_socket) {
        throw new Error('Method not implemented.');
    }
    writeContinue(_callback) {
        throw new Error('Method not implemented.');
    }
    writeEarlyHints(_hints, _callback) {
        throw new Error('Method not implemented.');
    }
    writeHead(_statusCode, _statusMessage, _headers) {
        throw new Error('Method not implemented.');
    }
    writeProcessing() {
        throw new Error('Method not implemented.');
    }
    setTimeout(_msecs, _callback) {
        throw new Error('Method not implemented.');
    }
    setHeader(name, value) {
        return this.set(name, value);
    }
    appendHeader(_name, _value) {
        throw new Error('Method not implemented.');
    }
    getHeader(name) {
        return this.headers[name];
    }
    getHeaders() {
        return this.headers;
    }
    getHeaderNames() {
        throw new Error('Method not implemented.');
    }
    hasHeader(_name) {
        throw new Error('Method not implemented.');
    }
    removeHeader(_name) {
        throw new Error('Method not implemented.');
    }
    addTrailers(_headers) {
        throw new Error('Method not implemented.');
    }
    flushHeaders() {
        throw new Error('Method not implemented.');
    }
    _write(_chunk, _encoding, _callback) {
        throw new Error('Method not implemented.');
    }
    _writev(_chunks, _callback) {
        throw new Error('Method not implemented.');
    }
    _construct(_callback) {
        throw new Error('Method not implemented.');
    }
    _destroy(_error, _callback) {
        throw new Error('Method not implemented.');
    }
    _final(_callback) {
        throw new Error('Method not implemented.');
    }
    write(_chunk, _encoding, _callback) {
        throw new Error('Method not implemented.');
    }
    setDefaultEncoding(_encoding) {
        throw new Error('Method not implemented.');
    }
    end(_chunk, _encoding, _cb) {
        throw new Error('Method not implemented.');
    }
    cork() {
        throw new Error('Method not implemented.');
    }
    uncork() {
        throw new Error('Method not implemented.');
    }
    destroy(_error) {
        throw new Error('Method not implemented.');
    }
    addListener(_event, _listener) {
        throw new Error('Method not implemented.');
    }
    emit(_event, _src, ..._rest) {
        throw new Error('Method not implemented.');
    }
    on(_event, _listener) {
        throw new Error('Method not implemented.');
    }
    once(_event, _listener) {
        throw new Error('Method not implemented.');
    }
    prependListener(_event, _listener) {
        throw new Error('Method not implemented.');
    }
    prependOnceListener(_event, _listener) {
        throw new Error('Method not implemented.');
    }
    removeListener(_event, _listener) {
        throw new Error('Method not implemented.');
    }
    pipe(_destination, _options) {
        throw new Error('Method not implemented.');
    }
    compose(_stream, _options) {
        throw new Error('Method not implemented.');
    }
    off(_eventName, _listener) {
        throw new Error('Method not implemented.');
    }
    removeAllListeners(_event) {
        throw new Error('Method not implemented.');
    }
    setMaxListeners(_n) {
        throw new Error('Method not implemented.');
    }
    getMaxListeners() {
        throw new Error('Method not implemented.');
    }
    // eslint-disable-next-line @typescript-eslint/ban-types
    listeners(_eventName) {
        throw new Error('Method not implemented.');
    }
    // eslint-disable-next-line @typescript-eslint/ban-types
    rawListeners(_eventName) {
        throw new Error('Method not implemented.');
    }
    // eslint-disable-next-line @typescript-eslint/ban-types
    listenerCount(_eventName, _listener) {
        throw new Error('Method not implemented.');
    }
    eventNames() {
        throw new Error('Method not implemented.');
    }
}
exports.ResponseImpl = ResponseImpl;
//# sourceMappingURL=response.js.map