import { Response } from './response';
import { NextFunction, Request } from 'express';
import { ResponseValidator } from './types';
/**
 * Handles the route subject to the client request, it does act as a express middleware.
 *
 */
export declare class RouteHandler {
    private readonly api;
    private readonly responseValidator;
    private readonly applicationContext;
    private readonly environment;
    private readonly requestBodyParser;
    private _interface;
    constructor(applicationContext: any, api: any, responseValidator: ResponseValidator, environment: any);
    /**
     * Handle the request from the client forwarding the request to the Interface that implement the
     * method defined on the API operation identifier.
     *
     * @param {any} req the express request object
     * @param {any} res the express response object
     * @param {Function} next a callback to propagate the handling action to the next middleware.
     *
     * @public
     */
    handle(req: Request, res: Response, next: NextFunction): void;
    _doHandleRequest(req: Request): any;
    /**
     * Collect the parameters defined as part of the OpenAPI definition.
     * @param {Object} req the express request
     */
    private collectParameters;
    handleApiResponse(answer: any, res: Response, next: NextFunction): any;
    private handleError;
    private sendResponse;
    /**
     * Normalise the response from the API to an instance of Response
     * @param {Any} answer the response from the API
     * @returns {Response}
     *
     * @private
     */
    /**
     * Lookup the interface that can handle the defined operationId for the API.
     * @returns {Interface}
     *
     * @private
     */
    private ensureInterface;
    /**
     * Define tge scope as transient so that a new instance will be created for every request
     *
     * @static
     * @public
     */
    static scope(): string;
}
